Discover Packages
github.com/mohammadiliyash/ms-contact-manager
app
models
database
package
Version:
v0.0.0-...-3220a8e
Opens a new window with list of versions in this module.
Published: Jul 18, 2019
License: Unlicense
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type Contact struct {
ContactID int `gorm:"primary_key"`
ContactName string `gorm:"type:varchar(50)”`
ContactAddress string `gorm:"type:varchar(500)”`
ContactEmail string `gorm:"type:varchar(50)”`
}
Contact ...
type Customer struct {
CustomerID int `gorm:"primary_key"`
CustomerName int `gorm:"type:varchar(50)”`
Contacts []Contact `gorm:"ForeignKey:CustomerId"`
}
Customer ...
Source Files
¶
Click to show internal directories.
Click to hide internal directories.