config

package
v0.0.0-...-3220a8e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 18, 2019 License: Unlicense Imports: 4 Imported by: 0

Documentation

Index

Constants

const AppName = "ms-contact-manager"

Variables

This section is empty.

Functions

func Initialize

func Initialize()

func SetConfig

func SetConfig(conf *MSCMConfig)

SetConfig bypasses the usual config override and validation behavior. It is intended to be used by unit tests.

Types

type MSCMConfig

type MSCMConfig struct {
	Environment string `yaml:"environment"`
	Key         string `yaml:"key"`
	SQLServer   string `yaml:"SQLServer"`
	SQLUsername string `yaml:"SQLUsername"`
	SQLPassword string `yaml:"SQLPassword"`
}
var Config *MSCMConfig

Config for the micro-service

Jump to